import { ClipsMusicAttributionInfo, EdgeFollowClass, Typename, User } from '.';
export interface IGPostMetadata {
    /** an Instagram Username */
    username: string;
    /** Instagram Full Name */
    name: string;
    /** media id */
    media_id: string;
    /** post shortcode */
    shortcode: string;
    /** a timestamp of posted media */
    taken_at_timestamp: number;
    /** the number of user who like a instagram post */
    likes: number;
    /** an caption from instagram post */
    caption: string;
    /** total media */
    media_count: number;
    /** comment count */
    comment_count: number;
    /** media urls */
    links: links[];
}
export interface links {
    type: string;
    /** url of downloadable media */
    url: string;
    dimensions: Dimensions;
}
export interface PostGraphQL {
    shortcode_media: ShortcodeMedia;
}
export interface ShortcodeMedia extends ViewerInfo {
    [x: string]: any;
    __typename: string;
    id: string;
    shortcode: string;
    dimensions: Dimensions;
    gating_info: null;
    fact_check_overall_rating: null;
    fact_check_information: null;
    sensitivity_friction_info: null;
    sharing_friction_info: SharingFrictionInfo;
    media_overlay_info: null;
    media_preview: null;
    video_url: string;
    display_url: string;
    display_resources: DisplayResource[];
    is_video: boolean;
    tracking_token: string;
    upcoming_event: null;
    edge_media_to_tagged_user: EdgeMediaToTaggedUser;
    edge_media_to_caption: EdgeMediaToCaptionClass;
    can_see_insights_as_brand: boolean;
    caption_is_edited: boolean;
    has_ranked_comments: boolean;
    like_and_view_counts_disabled: boolean;
    edge_media_to_parent_comment: EdgeMediaToParentCommentClass;
    edge_media_to_hoisted_comment: EdgeMediaToCaptionClass;
    edge_media_preview_comment: EdgeMediaPreview;
    comments_disabled: boolean;
    commenting_disabled_for_viewer: boolean;
    taken_at_timestamp: number;
    edge_media_preview_like: EdgeMediaPreview;
    edge_media_to_sponsor_user: EdgeMediaToCaptionClass;
    is_affiliate: boolean;
    is_paid_partnership: boolean;
    location: null;
    owner: ShortcodeMediaOwner;
    is_ad: boolean;
    edge_web_media_to_related_media: EdgeMediaToCaptionClass;
    coauthor_producers: any[];
    edge_sidecar_to_children: EdgeSidecarToChildren;
    edge_related_profiles: EdgeMediaToCaptionClass;
    accessibility_caption: null;
    dash_info: DashInfo;
    has_audio: boolean;
    video_view_count: number;
    video_play_count: null;
    encoding_status: null;
    is_published: boolean;
    product_type: string;
    title: string;
    video_duration: number;
    thumbnail_src: string;
    clips_music_attribution_info: null;
}
export interface ViewerInfo {
    viewer_has_liked: boolean;
    viewer_has_saved: boolean;
    viewer_has_saved_to_collection: boolean;
    viewer_in_photo_of_you: boolean;
    viewer_can_reshare: boolean;
}
export interface DashInfo {
    is_dash_eligible: boolean;
    video_dash_manifest: string;
    number_of_qualities: number;
}
/**
 * Media pixels dimensions
 */
export interface Dimensions {
    height: number;
    width: number;
}
export interface DisplayResource {
    src: string;
    config_width: number;
    config_height: number;
}
export interface EdgeMediaPreview {
    count: number;
    edges: EdgeMediaPreviewCommentEdge[];
}
export interface EdgeMediaToParentCommentClass {
    count: number;
    page_info: PageInfo;
    edges: EdgeMediaPreviewCommentEdge[];
}
export interface PurpleNode extends ViewerInfo {
    __typename: Typename;
    id: string;
    text: string;
    created_at: number;
    did_report_as_spam: boolean;
    edge_liked_by: EdgeFollowedByClass;
    is_restricted_pending: boolean;
    edge_threaded_comments?: EdgeMediaToParentCommentClass;
    shortcode: string;
    dimensions: Dimensions;
    display_url: string;
    edge_media_to_tagged_user: EdgeMediaToTaggedUser;
    fact_check_overall_rating: null;
    fact_check_information: null;
    gating_info: null;
    sensitivity_friction_info: any;
    sharing_friction_info: SharingFrictionInfo;
    media_overlay_info: null;
    media_preview: null | string;
    owner: User;
    is_video: boolean;
    has_upcoming_event: boolean;
    accessibility_caption: null | string;
    edge_media_to_caption: EdgeMediaToCaptionClass;
    edge_media_to_comment: EdgeFollowClass;
    comments_disabled: boolean;
    taken_at_timestamp: number;
    edge_media_preview_like: EdgeFollowClass;
    location: Location | null;
    thumbnail_src: string;
    thumbnail_resources: DisplayResource[];
    coauthor_producers: any[];
    dash_info?: DashInfo;
    has_audio?: boolean;
    tracking_token?: string;
    video_url?: string;
    video_view_count?: number;
    felix_profile_grid_crop?: null;
    product_type?: string;
    clips_music_attribution_info?: ClipsMusicAttributionInfo;
    edge_sidecar_to_children?: EdgeSidecarToChildren;
    pinned_for_users: any[];
    nft_asset_info: any;
    edge_media_to_sponsor_user: EdgeMediaToCaptionClass;
    is_affiliate: boolean;
    is_paid_partnership: boolean;
}
export interface EdgeMediaPreviewCommentEdge {
    node: PurpleNode;
}
export interface PageInfo {
    has_next_page: boolean;
    end_cursor: null;
}
export interface EdgeFollowedByClass {
    count: number;
}
export interface NodeOwner {
    id: string;
    is_verified: boolean;
    profile_pic_url: string;
    username: string;
}
export interface EdgeMediaToCaptionClass {
    edges: EdgeMediaToCaptionEdge[];
}
export interface EdgeMediaToCaptionEdge {
    node: FluffyNode;
}
export interface FluffyNode {
    text: string;
}
export interface EdgeMediaToTaggedUser {
    edges: EdgeMediaToTaggedUserEdge[];
}
export interface EdgeMediaToTaggedUserEdge {
    node: TentacledNode;
}
export interface TentacledNode {
    user: UserNode;
    x: number;
    y: number;
}
export interface UserNode {
    full_name: string;
    followed_by_viewer: boolean;
    id: string;
    is_verified: boolean;
    profile_pic_url: string;
    username: string;
}
export interface EdgeSidecarToChildren {
    edges: EdgeSidecarToChildrenEdge[];
}
export interface EdgeSidecarToChildrenEdge {
    __typename: string;
    node: StickyNode;
}
export interface StickyNode {
    __typename: string;
    id: string;
    shortcode: string;
    dimensions: Dimensions;
    gating_info: null;
    fact_check_overall_rating: null;
    fact_check_information: null;
    sensitivity_friction_info: null;
    sharing_friction_info: SharingFrictionInfo;
    media_overlay_info: null;
    media_preview: string;
    display_url: string;
    video_url: string;
    display_resources: DisplayResource[];
    accessibility_caption: string;
    is_video: boolean;
    tracking_token: string;
    upcoming_event: null;
    owner: User;
    has_upcoming_event: boolean;
    dash_info?: DashInfo;
    has_audio?: boolean;
    video_view_count?: number;
}
export interface SharingFrictionInfo {
    should_have_sharing_friction: boolean;
    bloks_app_url: null;
}
export interface ShortcodeMediaOwner {
    id: string;
    is_verified: boolean;
    profile_pic_url: string;
    username: string;
    blocked_by_viewer: boolean;
    restricted_by_viewer: boolean;
    followed_by_viewer: boolean;
    full_name: string;
    has_blocked_viewer: boolean;
    is_embeds_disabled: boolean;
    is_private: boolean;
    is_unpublished: boolean;
    requested_by_viewer: boolean;
    pass_tiering_recommendation: boolean;
    edge_owner_to_timeline_media: EdgeFollowedByClass;
    edge_followed_by: EdgeFollowedByClass;
}
